@@ -1,5 +1,6 @@
 from pystac import CatalogType, Collection, Item
 from pystac.extensions.item_assets import AssetDefinition, ItemAssetsExtension
+from pystac.extensions.raster import RasterExtension
 from pystac.extensions.scientific import ScientificExtension
 
 from .. import stac
@@ -42,6 +43,8 @@ def create_collection(catalog_type: CatalogType = DEFAULT_CATALOG_TYPE) -> Colle
     scientific.doi = DOI
     scientific.citation = CITATION
 
+    RasterExtension.add_to(collection)
+
     return collection
 
 
